@@ -1,20 +1,22 @@
-import os
-import subprocess
-import socket
-from plato.models.task import CustomEvalConfig
-from plato.models import PlatoTask, EvaluationResult
-from plato.models.flow import Flow
-from typing import Coroutine, List, Optional, Type, Dict, Any, TYPE_CHECKING
-import time
 import asyncio
-import random
-import logging
-from plato.exceptions import PlatoClientError
-from playwright.async_api import Page
-import yaml
 import json
-from urllib.parse import urlparse
+import logging
+import os
+import random
+import socket
+import subprocess
+import time
+from collections.abc import Coroutine
 from pathlib import Path
+from typing import TYPE_CHECKING, Any
+from urllib.parse import urlparse
+
+import yaml
+from playwright.async_api import Page
+
+from plato.exceptions import PlatoClientError
+from plato.models.flow import Flow
+from plato.models.task import CustomEvalConfig, EvaluationResult, PlatoTask
 
 logger = logging.getLogger(__name__)
 
@@ -39,22 +41,22 @@ class PlatoEnvironment:
         _heartbeat_task (Optional[asyncio.Task]): Task for sending periodic heartbeats
     """
 
-    _current_task: Optional[PlatoTask] = None
+    _current_task: PlatoTask | None = None
     _client: "Plato" = None
     id: str = None
     env_id: str = None
-    alias: Optional[str] = None
-    _run_session_id: Optional[str] = None
-    _heartbeat_task: Optional[asyncio.Task] = None
+    alias: str | None = None
+    _run_session_id: str | None = None
+    _heartbeat_task: asyncio.Task | None = None
     _heartbeat_interval: int = 30  # seconds
 
     def __init__(
         self,
         client: "Plato",
         id: str,
-        env_id: Optional[str] = None,
-        alias: Optional[str] = None,
-        active_session: Optional[str] = None,
+        env_id: str | None = None,
+        alias: str | None = None,
+        active_session: str | None = None,
         fast: bool = False,
     ):
         self._client = client
@@ -66,13 +68,13 @@ class PlatoEnvironment:
         self._run_session_id = active_session
         self.fast = fast
         self._db_tunnel_process = None
-        self._db_tunnel_info: Optional[Dict[str, Any]] = None
+        self._db_tunnel_info: dict[str, Any] | None = None
 
     async def login(
         self,
         page: Page,
         throw_on_login_error: bool = False,
-        screenshots_dir: Optional[Path] = None,
+        screenshots_dir: Path | None = None,
         dataset: str = "base",
         from_api: bool = False,
     ) -> None:
@@ -107,23 +109,19 @@ class PlatoEnvironment:
                         flows_yaml = body_text
                     scripts = yaml.safe_load(flows_yaml)
             except Exception as e:
-                raise PlatoClientError(f"Failed to load flows from API: {e}")
+                raise PlatoClientError(f"Failed to load flows from API: {e}") from e
         else:
             if not self.env_id:
-                raise PlatoClientError(
-                    "No env_id set on environment; cannot load flows"
-                )
+                raise PlatoClientError("No env_id set on environment; cannot load flows")
 
             # Load from repo path: python/src/plato/flows/{env_id}/scripts.yaml
-            flows_dir = os.path.join(
-                os.path.dirname(os.path.dirname(__file__)), "flows"
-            )
+            flows_dir = os.path.join(os.path.dirname(os.path.dirname(__file__)), "flows")
             scripts_path = os.path.join(flows_dir, self.env_id, "scripts.yaml")
             if not os.path.exists(scripts_path):
                 raise PlatoClientError(
                     f"Flow scripts not found for env_id '{self.env_id}' at {scripts_path}"
                 )
-            with open(scripts_path, "r") as f:
+            with open(scripts_path) as f:
                 scripts = yaml.safe_load(f)
 
         # Parse flows from Watchdog-style format
@@ -153,7 +151,7 @@ class PlatoEnvironment:
             else:
                 logger.warning("Failed to login")
 
-    async def wait_for_ready(self, timeout: Optional[float] = None) -> None:
+    async def wait_for_ready(self, timeout: float | None = None) -> None:
         """Wait for the environment to be ready.
 
         This method checks both the job status and worker health until everything is ready.
@@ -182,15 +180,11 @@ class PlatoEnvironment:
             await asyncio.sleep(current_delay + jitter)
 
             if timeout and time.time() - start_time > timeout:
-                raise RuntimeError(
-                    "Environment failed to start - job never entered running state"
-                )
+                raise RuntimeError("Environment failed to start - job never entered running state")
 
             # Exponential backoff
             current_delay = min(current_delay * 2, max_delay)
-            logger.debug(
-                f"Waiting for job {self.id} to be running: {current_delay} seconds"
-            )
+            logger.debug(f"Waiting for job {self.id} to be running: {current_delay} seconds")
 
         # wait for the worker to be ready and healthy
         current_delay = base_delay  # Reset delay for worker health check
@@ -205,15 +199,11 @@ class PlatoEnvironment:
 
             if timeout and time.time() - start_time > timeout:
                 error_msg = worker_status.get("error", "Unknown error")
-                raise RuntimeError(
-                    f"Environment failed to start - worker not ready: {error_msg}"
-                )
+                raise RuntimeError(f"Environment failed to start - worker not ready: {error_msg}")
 
             # Exponential backoff
             current_delay = min(current_delay * 2, max_delay)
-            logger.debug(
-                f"Waiting for worker {self.id} to be ready: {current_delay} seconds"
-            )
+            logger.debug(f"Waiting for worker {self.id} to be ready: {current_delay} seconds")
 
         # Start the heartbeat task if not already running
         await self._start_heartbeat()
@@ -231,9 +221,9 @@ class PlatoEnvironment:
 
     async def __aexit__(
         self,
-        exc_type: Optional[Type[BaseException]],
-        exc_val: Optional[BaseException],
-        exc_tb: Optional[Type[BaseException]],
+        exc_type: type[BaseException] | None,
+        exc_val: BaseException | None,
+        exc_tb: type[BaseException] | None,
     ) -> None:
         """Exit the async context manager.
 
@@ -261,9 +251,9 @@ class PlatoEnvironment:
 
     async def reset(
         self,
-        task: Optional[PlatoTask] = None,
-        agent_version: Optional[str] = None,
-        model: Optional[str] = None,
+        task: PlatoTask | None = None,
+        agent_version: str | None = None,
+        model: str | None = None,
         load_authenticated: bool = False,
         **kwargs,
     ) -> str:
@@ -335,7 +325,7 @@ class PlatoEnvironment:
             finally:
                 self._heartbeat_task = None
 
-    async def get_state(self, merge_mutations: bool = False) -> Dict[str, Any]:
+    async def get_state(self, merge_mutations: bool = False) -> dict[str, Any]:
         """Get the current state of the environment.
 
         Returns:
@@ -348,9 +338,7 @@ class PlatoEnvironment:
             raise PlatoClientError("No active run session. Call reset() first.")
         return await self._client.get_environment_state(self.id, merge_mutations)
 
-    async def get_state_mutations(
-        self, merge_mutations: bool = False
-    ) -> List[Dict[str, Any]]:
+    async def get_state_mutations(self, merge_mutations: bool = False) -> list[dict[str, Any]]:
         """Get a list of state mutations that have occurred in the environment.
 
         Returns:
@@ -362,7 +350,7 @@ class PlatoEnvironment:
         state = await self.get_state(merge_mutations)
         return state.get("mutations", [])
 
-    def _get_nested_value(self, data: Dict[str, Any], key_path: str) -> Any:
+    def _get_nested_value(self, data: dict[str, Any], key_path: str) -> Any:
         """Get a value from a nested dictionary using dotted notation.
 
         Args:
@@ -409,9 +397,7 @@ class PlatoEnvironment:
             raise PlatoClientError("No active run session. Call reset() first.")
 
         if not self._current_task or not self._current_task.eval_config:
-            logger.warning(
-                f"No evaluation config found for task: {self._current_task.name}"
-            )
+            logger.warning(f"No evaluation config found for task: {self._current_task.name}")
             raise PlatoClientError("No evaluation config found for task")
 
         eval_config = self._current_task.eval_config
@@ -427,9 +413,7 @@ class PlatoEnvironment:
                     result = await result
                 if isinstance(result, tuple):
                     success, reason = result
-                    return EvaluationResult(
-                        success=success, reason=None if success else reason
-                    )
+                    return EvaluationResult(success=success, reason=None if success else reason)
                 else:
                     # Handle legacy score functions that return just a boolean
                     return EvaluationResult(
@@ -437,9 +421,7 @@ class PlatoEnvironment:
                         reason=None if result else "Custom evaluation failed",
                     )
             except Exception as e:
-                return EvaluationResult(
-                    success=False, reason=f"Custom evaluation error: {str(e)}"
-                )
+                return EvaluationResult(success=False, reason=f"Custom evaluation error: {str(e)}")
 
         else:
             return EvaluationResult(
@@ -447,14 +429,12 @@ class PlatoEnvironment:
             )
 
     async def evaluate(
-        self, value: Optional[Any] = None, agent_version: Optional[str] = None
+        self, value: Any | None = None, agent_version: str | None = None
     ) -> EvaluationResult:
         if not self._run_session_id:
             raise PlatoClientError("No active run session. Call reset() first.")
 
-        if self._current_task and isinstance(
-            self._current_task.eval_config, CustomEvalConfig
-        ):
+        if self._current_task and isinstance(self._current_task.eval_config, CustomEvalConfig):
             evaluation_result = await self.get_evaluation_result()
             state = await self.get_state()
             state = state.get("state", {})
@@ -466,9 +446,7 @@ class PlatoEnvironment:
             return evaluation_result
         else:
             # call /evaluate endpoint
-            response = await self._client.evaluate(
-                self._run_session_id, value, agent_version
-            )
+            response = await self._client.evaluate(self._run_session_id, value, agent_version)
             if not response:
                 raise PlatoClientError("No evaluation result found")
             result = response["result"]
@@ -506,7 +484,7 @@ class PlatoEnvironment:
             raise PlatoClientError("No active run session. Call reset() first.")
         return await self._client.get_live_view_url(self.id)
 
-    async def get_proxy_config(self) -> Dict[str, str]:
+    async def get_proxy_config(self) -> dict[str, str]:
         """Get the proxy configuration for this environment.
 
         Returns:
@@ -553,7 +531,7 @@ class PlatoEnvironment:
                 "password": self._run_session_id,
             }
         except Exception as e:
-            raise PlatoClientError(str(e))
+            raise PlatoClientError(str(e)) from e
 
     async def get_public_url(self) -> str:
         """Get the public URL for accessing this environment.
@@ -592,7 +570,7 @@ class PlatoEnvironment:
             else:
                 raise PlatoClientError("Unknown base URL")
         except Exception as e:
-            raise PlatoClientError(str(e))
+            raise PlatoClientError(str(e)) from e
 
     async def get_session_url(self) -> str:
         """Get the URL for accessing the session of the environment."""
@@ -601,7 +579,7 @@ class PlatoEnvironment:
         root_url = self._client.base_url.split("/api")[0]
         return os.path.join(root_url, "sessions", f"{self._run_session_id}/")
 
-    def get_db_login_info(self, database: Optional[str] = None) -> Dict[str, Any]:
+    def get_db_login_info(self, database: str | None = None) -> dict[str, Any]:
         """Return database login information for this simulator.
 
         The defaults are sourced from plato.flows.db_logins.SIM_DB_CONFIGS.
@@ -616,7 +594,7 @@ class PlatoEnvironment:
         try:
             from plato.flows.db_logins import SIM_DB_CONFIGS
         except Exception as e:
-            raise PlatoClientError(f"Failed to load DB login presets: {e}")
+            raise PlatoClientError(f"Failed to load DB login presets: {e}") from e
 
         key = self.env_id or self.alias or self.id
         cfg = SIM_DB_CONFIGS.get(key)
@@ -627,22 +605,18 @@ class PlatoEnvironment:
 
         return {
             "db_type": cfg.get("db_type", "postgresql"),
-            "user": cfg.get(
-                "user", "postgres" if cfg.get("db_type") == "postgresql" else "root"
-            ),
+            "user": cfg.get("user", "postgres" if cfg.get("db_type") == "postgresql" else "root"),
             "password": cfg.get("password", ""),
             "dest_port": int(
-                cfg.get(
-                    "dest_port", 5432 if cfg.get("db_type") == "postgresql" else 3306
-                )
+                cfg.get("dest_port", 5432 if cfg.get("db_type") == "postgresql" else 3306)
             ),
             "databases": cfg.get("databases", []),
         }
 
     async def start_db_tunnel(
         self,
-        dest_port: Optional[int] = None,
-        local_port: Optional[int] = None,
+        dest_port: int | None = None,
+        local_port: int | None = None,
     ) -> int:
         """Start a local TCP tunnel to the environment's database via Plato proxy.
 
@@ -680,14 +654,10 @@ class PlatoEnvironment:
 
         proxy_cfg = await self.get_proxy_config()
         server_url = proxy_cfg["server"]
-        parsed = urlparse(
-            server_url if "://" in server_url else f"https://{server_url}"
-        )
+        parsed = urlparse(server_url if "://" in server_url else f"https://{server_url}")
         proxy_host = parsed.hostname or server_url
         # Default ports: https -> 9000, http -> 8888 (local dev)
-        proxy_port = parsed.port or (
-            9000 if (parsed.scheme or "https") == "https" else 8888
-        )
+        proxy_port = parsed.port or (9000 if (parsed.scheme or "https") == "https" else 8888)
         use_tls = (parsed.scheme or "https") == "https"
 
         username = proxy_cfg["username"]
@@ -735,7 +705,7 @@ class PlatoEnvironment:
                 stderr=subprocess.PIPE,
             )
         except Exception as e:
-            raise PlatoClientError(f"Failed to start proxytunnel: {e}")
+            raise PlatoClientError(f"Failed to start proxytunnel: {e}") from e
 
         # Brief grace period to surface immediate failures
         await asyncio.sleep(0.3)
@@ -783,7 +753,7 @@ class PlatoEnvironment:
         # Close the environment through the API
         await self._client.close_environment(self.id)
 
-    async def backup(self) -> Dict[str, Any]:
+    async def backup(self) -> dict[str, Any]:
         """Create a backup of the environment.
 
         Returns:
@@ -795,9 +765,7 @@ class PlatoEnvironment:
         return await self._client.backup_environment(self.id)
 
     @staticmethod
-    async def from_id(
-        client: "Plato", id: str, fast: bool = False
-    ) -> "PlatoEnvironment":
+    async def from_id(client: "Plato", id: str, fast: bool = False) -> "PlatoEnvironment":
         """Create a new environment from an ID.
 
         Returns:
