@@ -1,10 +1,13 @@
-from pydantic import BaseModel, ConfigDict, field_serializer
-from typing import Any, Dict, Optional, Literal, List, Callable
+from collections.abc import Callable
 from enum import Enum
+from typing import Any, Literal
+
+from pydantic import BaseModel, ConfigDict, field_serializer
 
 
 class ScoringType(str, Enum):
     """Enum for different types of scoring in Plato tasks."""
+
     OUTPUT = "output"
     MUTATIONS = "mutations"
 
@@ -19,25 +22,31 @@ class BasePlatoEvalConfig(BaseModel):
         type (Literal["base", "state_mutation_match"]): The type of evaluation configuration.
             Can be either "base" or "state_mutation_match".
     """
+
     model_config = ConfigDict(arbitrary_types_allowed=True)
     type: Literal["state_mutation_match", "custom"]
 
+
 class StateMutationMatch(BaseModel):
     tablename: str
     action: Literal["INSERT", "UPDATE", "DELETE"]
-    values: Dict[str, Any]
+    values: dict[str, Any]
+
 
 class MutationVariable(BaseModel):
     type: Literal["mutation_variable"] = "mutation_variable"
     name: str
 
+
 class SemanticMatchVariable(BaseModel):
     type: Literal["semantic_match_variable"] = "semantic_match_variable"
     description: str
 
+
 class EnumMatchVariable(BaseModel):
     type: Literal["enum_match_variable"] = "enum_match_variable"
-    values: List[Any]
+    values: list[Any]
+
 
 class StateMutationMatchEvalConfig(BasePlatoEvalConfig):
     """Configuration for state mutation matching evaluation.
@@ -54,7 +63,7 @@ class StateMutationMatchEvalConfig(BasePlatoEvalConfig):
     """
 
     type: Literal["state_mutation_match"] = "state_mutation_match"
-    mutations: List[StateMutationMatch]
+    mutations: list[StateMutationMatch]
 
 
 class CustomEvalConfig(BasePlatoEvalConfig):
@@ -70,7 +79,8 @@ class CustomEvalConfig(BasePlatoEvalConfig):
 
     type: Literal["custom"] = "custom"
     score_fn: Callable
-    @field_serializer('score_fn')
+
+    @field_serializer("score_fn")
     def serialize_score_fn(self, score_fn: Callable, _info):
         return score_fn.__name__
 
@@ -84,19 +94,21 @@ class EvaluationResult(BaseModel):
     """
 
     success: bool
-    reason: Optional[str] = None
-    diffs: Optional[List[Dict[str, Any]]] = None
-    expected_mutations: Optional[List[Dict[str, Any]]] = None
-    actual_mutations: Optional[List[Dict[str, Any]]] = None
+    reason: str | None = None
+    diffs: list[dict[str, Any]] | None = None
+    expected_mutations: list[dict[str, Any]] | None = None
+    actual_mutations: list[dict[str, Any]] | None = None
 
 
 class PlatoTaskMetadata(BaseModel):
     """Metadata for a Plato task."""
-    reasoning_level: Optional[Literal["level_1", "level_2", "level_3", "level_4", "level_5"]] = None
-    skills: Optional[List[str]] = None
-    capabilities: Optional[List[str]] = None
-    tags: Optional[List[str]] = None
-    rejected: Optional[bool] = False
+
+    reasoning_level: Literal["level_1", "level_2", "level_3", "level_4", "level_5"] | None = None
+    skills: list[str] | None = None
+    capabilities: list[str] | None = None
+    tags: list[str] | None = None
+    rejected: bool | None = False
+
 
 class PlatoTask(BaseModel):
     """Represents a task in the Plato system.
@@ -109,24 +121,25 @@ class PlatoTask(BaseModel):
         prompt (str): The prompt describing what should be done in this task.
         start_url (str): The URL where the task should begin execution.
     """
+
     public_id: str
     name: str
     prompt: str
     env_id: str
     start_url: str
-    dataset_name: Optional[str] = None
-    eval_config: Optional[BasePlatoEvalConfig] = None
-    average_time: Optional[float] = None
-    average_steps: Optional[int] = None
-    num_validator_human_scores: Optional[int] = None
-    default_scoring_config: Optional[Dict[str, Any]] = None
-    scoring_type: List[ScoringType] = [ScoringType.MUTATIONS]
-    output_schema: Optional[Dict[str, Any]] = None
-    is_sample: Optional[bool] = False
-    simulator_artifact_id: Optional[str] = None
-    metadata: Optional[PlatoTaskMetadata] = None
-    version: Optional[int] = 1
+    dataset_name: str | None = None
+    eval_config: BasePlatoEvalConfig | None = None
+    average_time: float | None = None
+    average_steps: int | None = None
+    num_validator_human_scores: int | None = None
+    default_scoring_config: dict[str, Any] | None = None
+    scoring_type: list[ScoringType] = [ScoringType.MUTATIONS]
+    output_schema: dict[str, Any] | None = None
+    is_sample: bool | None = False
+    simulator_artifact_id: str | None = None
+    metadata: PlatoTaskMetadata | None = None
+    version: int | None = 1
 
-    @field_serializer('eval_config')
-    def serialize_eval_config(self, eval_config: Optional[BasePlatoEvalConfig], _info):
+    @field_serializer("eval_config")
+    def serialize_eval_config(self, eval_config: BasePlatoEvalConfig | None, _info):
         return eval_config.model_dump() if eval_config else None
