@@ -7,19 +7,18 @@ Simple Python wrapper around the Go Sandbox SDK using C bindings.
 import ctypes
 import json
 import logging
-import os
 from pathlib import Path
-from typing import Optional, Dict, Any, List, Union
+from typing import Any
 
 from plato.models.sandbox import (
-    Sandbox,
-    SimConfigDataset,
-    DBConfig,
     CreateSnapshotRequest,
     CreateSnapshotResponse,
+    DBConfig,
+    Sandbox,
+    SimConfigDataset,
+    SimulatorListItem,
     StartWorkerRequest,
     StartWorkerResponse,
-    SimulatorListItem,
 )
 
 # Set up logging
@@ -29,7 +28,7 @@ logger.setLevel(logging.INFO)
 # Only add handler if none exists (avoid duplicate logs)
 if not logger.handlers:
     handler = logging.StreamHandler()
-    handler.setFormatter(logging.Formatter('[PLATO-PY] %(asctime)s - %(levelname)s - %(message)s'))
+    handler.setFormatter(logging.Formatter("[PLATO-PY] %(asctime)s - %(levelname)s - %(message)s"))
     logger.addHandler(handler)
 
 
@@ -66,6 +65,7 @@ def _find_lib():
 _lib = None
 _lib_path = None
 
+
 def _get_lib():
     """Get the loaded library, loading it if necessary"""
     global _lib, _lib_path
@@ -85,7 +85,7 @@ def _get_lib():
             ctypes.c_char_p,  # alias
             ctypes.c_char_p,  # artifactID
             ctypes.c_char_p,  # service
-            ctypes.c_int,     # timeout
+            ctypes.c_int,  # timeout
         ]
         _lib.plato_create_sandbox.restype = ctypes.c_void_p
 
@@ -131,7 +131,12 @@ def _get_lib():
         _lib.plato_gitea_create_simulator_repo.argtypes = [ctypes.c_char_p, ctypes.c_int]
         _lib.plato_gitea_create_simulator_repo.restype = ctypes.c_void_p
 
-        _lib.plato_proxytunnel_start.argtypes = [ctypes.c_char_p, ctypes.c_char_p, ctypes.c_int, ctypes.c_int]
+        _lib.plato_proxytunnel_start.argtypes = [
+            ctypes.c_char_p,
+            ctypes.c_char_p,
+            ctypes.c_int,
+            ctypes.c_int,
+        ]
         _lib.plato_proxytunnel_start.restype = ctypes.c_void_p
 
         _lib.plato_proxytunnel_stop.argtypes = [ctypes.c_char_p, ctypes.c_char_p]
@@ -143,10 +148,22 @@ def _get_lib():
         _lib.plato_gitea_push_to_hub.argtypes = [ctypes.c_char_p, ctypes.c_char_p, ctypes.c_char_p]
         _lib.plato_gitea_push_to_hub.restype = ctypes.c_void_p
 
-        _lib.plato_gitea_merge_to_main.argtypes = [ctypes.c_char_p, ctypes.c_char_p, ctypes.c_char_p]
+        _lib.plato_gitea_merge_to_main.argtypes = [
+            ctypes.c_char_p,
+            ctypes.c_char_p,
+            ctypes.c_char_p,
+        ]
         _lib.plato_gitea_merge_to_main.restype = ctypes.c_void_p
 
-        _lib.plato_setup_ssh.argtypes = [ctypes.c_char_p, ctypes.c_char_p, ctypes.c_int, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_char_p]
+        _lib.plato_setup_ssh.argtypes = [
+            ctypes.c_char_p,
+            ctypes.c_char_p,
+            ctypes.c_int,
+            ctypes.c_char_p,
+            ctypes.c_char_p,
+            ctypes.c_char_p,
+            ctypes.c_char_p,
+        ]
         _lib.plato_setup_ssh.restype = ctypes.c_void_p
 
         _lib.plato_free_string.argtypes = [ctypes.c_void_p]
@@ -164,7 +181,7 @@ def _call_and_free(lib, result_ptr):
         s = ctypes.cast(result_ptr, ctypes.c_char_p).value
         if s is None:
             raise RuntimeError("Got null string from C function")
-        return s.decode('utf-8')
+        return s.decode("utf-8")
     finally:
         # Always free the C string
         lib.plato_free_string(result_ptr)
@@ -214,7 +231,7 @@ class PlatoSandboxClient:
         logger.debug(f"Initializing PlatoSandboxClient with base_url={base_url}")
 
         # Helpful check: detect if user accidentally passed URL as api_key (old signature)
-        if api_key.startswith('http://') or api_key.startswith('https://'):
+        if api_key.startswith("http://") or api_key.startswith("https://"):
             raise ValueError(
                 "It looks like you passed a URL as the api_key. "
                 "The signature has changed to: PlatoSandboxClient(api_key, base_url='https://plato.so/api'). "
@@ -224,23 +241,20 @@ class PlatoSandboxClient:
         self._base_url = base_url
         self._sandbox_configs = {}  # Cache configs by sandbox public_id
         lib = _get_lib()
-        result_ptr = lib.plato_new_client(
-            base_url.encode('utf-8'),
-            api_key.encode('utf-8')
-        )
+        result_ptr = lib.plato_new_client(base_url.encode("utf-8"), api_key.encode("utf-8"))
         self._client_id = _call_and_free(lib, result_ptr)
         logger.info(f"Created PlatoSandboxClient with client_id={self._client_id}")
 
     def create_sandbox(
         self,
-        config: Optional[SimConfigDataset] = None,
+        config: SimConfigDataset | None = None,
         dataset: str = "base",
         alias: str = "sandbox",
-        artifact_id: Optional[str] = None,
+        artifact_id: str | None = None,
         service: str = "",
         wait: bool = True,
         timeout: int = 600,
-        sandbox_timeout: int | None = None
+        sandbox_timeout: int | None = None,
     ) -> Sandbox:
         """
         Create a new VM sandbox
@@ -304,50 +318,49 @@ class PlatoSandboxClient:
                     "memory": 512,
                     "disk": 10240,
                     "app_port": 8080,
-                    "plato_messaging_port": 7000
+                    "plato_messaging_port": 7000,
                 },
-                "metadata": {
-                    "name": "Default"
-                }
+                "metadata": {"name": "Default"},
             }
             config_json = json.dumps(config_dict)
         elif config is not None:
             # Convert config to dict if it's a Pydantic model
             # Use mode='json' to properly serialize enums to their values
-            config_dict = config.model_dump(mode='json', exclude_none=True)
+            config_dict = config.model_dump(mode="json", exclude_none=True)
             config_json = json.dumps(config_dict)
         else:
             config_json = "{}"
 
-        logger.info(f"Creating sandbox: artifact_id={artifact_id}, service={service}, dataset={dataset}, sandbox_timeout={sandbox_timeout}")
+        logger.info(
+            f"Creating sandbox: artifact_id={artifact_id}, service={service}, dataset={dataset}, sandbox_timeout={sandbox_timeout}"
+        )
         lib = _get_lib()
         result_ptr = lib.plato_create_sandbox(
-            self._client_id.encode('utf-8'),
-            config_json.encode('utf-8'),
-            dataset.encode('utf-8'),
-            alias.encode('utf-8'),
-            artifact_id.encode('utf-8') if artifact_id else b'',
-            service.encode('utf-8'),
+            self._client_id.encode("utf-8"),
+            config_json.encode("utf-8"),
+            dataset.encode("utf-8"),
+            alias.encode("utf-8"),
+            artifact_id.encode("utf-8") if artifact_id else b"",
+            service.encode("utf-8"),
             ctypes.c_int(sandbox_timeout if sandbox_timeout is not None else -1),
         )
 
         result_str = _call_and_free(lib, result_ptr)
         response = json.loads(result_str)
 
-        if 'error' in response:
+        if "error" in response:
             logger.error(f"Failed to create sandbox: {response['error']}")
             raise RuntimeError(f"Failed to create sandbox: {response['error']}")
 
         sandbox = Sandbox(**response)
-        logger.info(f"Sandbox created: public_id={sandbox.public_id}, job_group_id={sandbox.job_group_id}")
+        logger.info(
+            f"Sandbox created: public_id={sandbox.public_id}, job_group_id={sandbox.job_group_id}"
+        )
         logger.debug(f"Automatic heartbeat started for job_group_id={sandbox.job_group_id}")
 
         # Cache the config and dataset for later use (e.g., in setup_ssh)
         if config is not None:
-            self._sandbox_configs[sandbox.public_id] = {
-                'config': config,
-                'dataset': dataset
-            }
+            self._sandbox_configs[sandbox.public_id] = {"config": config, "dataset": dataset}
 
         # Wait for sandbox to be ready if requested
         if wait and sandbox.correlation_id:
@@ -372,14 +385,13 @@ class PlatoSandboxClient:
         logger.info(f"Closing sandbox: public_id={public_id}")
         lib = _get_lib()
         result_ptr = lib.plato_delete_sandbox(
-            self._client_id.encode('utf-8'),
-            public_id.encode('utf-8')
+            self._client_id.encode("utf-8"), public_id.encode("utf-8")
         )
 
         result_str = _call_and_free(lib, result_ptr)
         response = json.loads(result_str)
 
-        if 'error' in response:
+        if "error" in response:
             logger.error(f"Failed to close sandbox {public_id}: {response['error']}")
             raise RuntimeError(f"Failed to close sandbox: {response['error']}")
 
@@ -389,9 +401,7 @@ class PlatoSandboxClient:
         logger.info(f"Sandbox {public_id} closed successfully (heartbeat stopped automatically)")
 
     def create_snapshot(
-        self,
-        public_id: str,
-        request: CreateSnapshotRequest
+        self, public_id: str, request: CreateSnapshotRequest
     ) -> CreateSnapshotResponse:
         """
         Create a snapshot of a sandbox
@@ -413,28 +423,24 @@ class PlatoSandboxClient:
         """
         # Convert to dict if Pydantic model
         # Use mode='json' to properly serialize enums to their values
-        request_dict = request.model_dump(mode='json', exclude_none=True)
+        request_dict = request.model_dump(mode="json", exclude_none=True)
         request_json = json.dumps(request_dict)
 
         lib = _get_lib()
         result_ptr = lib.plato_create_snapshot(
-            self._client_id.encode('utf-8'),
-            public_id.encode('utf-8'),
-            request_json.encode('utf-8')
+            self._client_id.encode("utf-8"), public_id.encode("utf-8"), request_json.encode("utf-8")
         )
 
         result_str = _call_and_free(lib, result_ptr)
         response = json.loads(result_str)
 
-        if 'error' in response:
+        if "error" in response:
             raise RuntimeError(f"Failed to create snapshot: {response['error']}")
 
         return CreateSnapshotResponse(**response)
 
     def create_checkpoint(
-        self,
-        public_id: str,
-        request: CreateSnapshotRequest
+        self, public_id: str, request: CreateSnapshotRequest
     ) -> CreateSnapshotResponse:
         """
         Create a checkpoint of a sandbox
@@ -456,20 +462,18 @@ class PlatoSandboxClient:
         """
         # Convert to dict if Pydantic model
         # Use mode='json' to properly serialize enums to their values
-        request_dict = request.model_dump(mode='json', exclude_none=True)
+        request_dict = request.model_dump(mode="json", exclude_none=True)
         request_json = json.dumps(request_dict)
 
         lib = _get_lib()
         result_ptr = lib.plato_create_checkpoint(
-            self._client_id.encode('utf-8'),
-            public_id.encode('utf-8'),
-            request_json.encode('utf-8')
+            self._client_id.encode("utf-8"), public_id.encode("utf-8"), request_json.encode("utf-8")
         )
 
         result_str = _call_and_free(lib, result_ptr)
         response = json.loads(result_str)
 
-        if 'error' in response:
+        if "error" in response:
             raise RuntimeError(f"Failed to create checkpoint: {response['error']}")
 
         return CreateSnapshotResponse(**response)
@@ -479,7 +483,7 @@ class PlatoSandboxClient:
         public_id: str,
         job_group_id: str,
         request: CreateSnapshotRequest,
-        db_config: Optional[Union[DBConfig, Dict[str, Any]]] = None
+        db_config: DBConfig | dict[str, Any] | None = None,
     ) -> CreateSnapshotResponse:
         """
         Create a snapshot with pre-snapshot database cleanup
@@ -506,7 +510,7 @@ class PlatoSandboxClient:
 
         Example:
             >>> from plato.models.sandbox import DBConfig, CreateSnapshotRequest
-            >>> 
+            >>>
             >>> # Using Pydantic model (recommended)
             >>> db_config = DBConfig(
             ...     db_type="postgresql",
@@ -542,14 +546,14 @@ class PlatoSandboxClient:
         logger.info(f"Creating snapshot with cleanup for sandbox {public_id}")
 
         # Convert request to dict if Pydantic model
-        request_dict = request.model_dump(mode='json', exclude_none=True)
+        request_dict = request.model_dump(mode="json", exclude_none=True)
         request_json = json.dumps(request_dict)
 
         # Convert db_config to JSON (or null if not provided)
         if db_config is None:
             db_config_json = "null"
         elif isinstance(db_config, DBConfig):
-            db_config_dict = db_config.model_dump(mode='json', exclude_none=True)
+            db_config_dict = db_config.model_dump(mode="json", exclude_none=True)
             db_config_json = json.dumps(db_config_dict)
         else:
             # Assume it's a dict
@@ -557,17 +561,17 @@ class PlatoSandboxClient:
 
         lib = _get_lib()
         result_ptr = lib.plato_create_snapshot_with_cleanup(
-            self._client_id.encode('utf-8'),
-            public_id.encode('utf-8'),
-            job_group_id.encode('utf-8'),
-            request_json.encode('utf-8'),
-            db_config_json.encode('utf-8')
+            self._client_id.encode("utf-8"),
+            public_id.encode("utf-8"),
+            job_group_id.encode("utf-8"),
+            request_json.encode("utf-8"),
+            db_config_json.encode("utf-8"),
         )
 
         result_str = _call_and_free(lib, result_ptr)
         response = json.loads(result_str)
 
-        if 'error' in response:
+        if "error" in response:
             logger.error(f"Failed to create snapshot with cleanup: {response['error']}")
             raise RuntimeError(f"Failed to create snapshot with cleanup: {response['error']}")
 
@@ -575,9 +579,7 @@ class PlatoSandboxClient:
         return CreateSnapshotResponse(**response)
 
     def start_worker(
-        self,
-        public_id: str,
-        request: Union[StartWorkerRequest, Dict[str, Any]]
+        self, public_id: str, request: StartWorkerRequest | dict[str, Any]
     ) -> StartWorkerResponse:
         """
         Start a Plato worker in a sandbox
@@ -604,27 +606,25 @@ class PlatoSandboxClient:
         # Convert to dict if Pydantic model
         if isinstance(request, StartWorkerRequest):
             # Use mode='json' to properly serialize enums to their values
-            request_dict = request.model_dump(mode='json', exclude_none=True)
+            request_dict = request.model_dump(mode="json", exclude_none=True)
         else:
             request_dict = request
         request_json = json.dumps(request_dict)
 
         lib = _get_lib()
         result_ptr = lib.plato_start_worker(
-            self._client_id.encode('utf-8'),
-            public_id.encode('utf-8'),
-            request_json.encode('utf-8')
+            self._client_id.encode("utf-8"), public_id.encode("utf-8"), request_json.encode("utf-8")
         )
 
         result_str = _call_and_free(lib, result_ptr)
         response = json.loads(result_str)
 
-        if 'error' in response:
+        if "error" in response:
             raise RuntimeError(f"Failed to start worker: {response['error']}")
 
         return StartWorkerResponse(**response)
 
-    def list_simulators(self) -> List[SimulatorListItem]:
+    def list_simulators(self) -> list[SimulatorListItem]:
         """
         List all available simulators
 
@@ -640,20 +640,18 @@ class PlatoSandboxClient:
             ...     print(f"{sim.name}: {sim.description}")
         """
         lib = _get_lib()
-        result_ptr = lib.plato_list_simulators(
-            self._client_id.encode('utf-8')
-        )
+        result_ptr = lib.plato_list_simulators(self._client_id.encode("utf-8"))
 
         result_str = _call_and_free(lib, result_ptr)
 
         # Check if it's an error response (dict with 'error' key)
         response = json.loads(result_str)
-        if isinstance(response, dict) and 'error' in response:
+        if isinstance(response, dict) and "error" in response:
             raise RuntimeError(f"Failed to list simulators: {response['error']}")
 
         return [SimulatorListItem(**item) for item in response]
 
-    def get_simulator_versions(self, simulator_name: str) -> List[Dict[str, Any]]:
+    def get_simulator_versions(self, simulator_name: str) -> list[dict[str, Any]]:
         """
         Get all versions for a specific simulator
 
@@ -673,24 +671,19 @@ class PlatoSandboxClient:
         """
         lib = _get_lib()
         result_ptr = lib.plato_get_simulator_versions(
-            self._client_id.encode('utf-8'),
-            simulator_name.encode('utf-8')
+            self._client_id.encode("utf-8"), simulator_name.encode("utf-8")
         )
 
         result_str = _call_and_free(lib, result_ptr)
 
         # Check if it's an error response (dict with 'error' key)
         response = json.loads(result_str)
-        if isinstance(response, dict) and 'error' in response:
+        if isinstance(response, dict) and "error" in response:
             raise RuntimeError(f"Failed to get versions: {response['error']}")
 
         return response
 
-    def wait_until_ready(
-        self,
-        correlation_id: str,
-        timeout: int = 600
-    ) -> None:
+    def wait_until_ready(self, correlation_id: str, timeout: int = 600) -> None:
         """
         Wait until an operation completes by monitoring SSE events
 
@@ -711,18 +704,16 @@ class PlatoSandboxClient:
         """
         lib = _get_lib()
         result_ptr = lib.plato_monitor_operation(
-            self._client_id.encode('utf-8'),
-            correlation_id.encode('utf-8'),
-            ctypes.c_int(timeout)
+            self._client_id.encode("utf-8"), correlation_id.encode("utf-8"), ctypes.c_int(timeout)
         )
 
         result_str = _call_and_free(lib, result_ptr)
         response = json.loads(result_str)
 
-        if 'error' in response:
+        if "error" in response:
             raise RuntimeError(f"Operation failed: {response['error']}")
 
-    def get_gitea_credentials(self) -> Dict[str, str]:
+    def get_gitea_credentials(self) -> dict[str, str]:
         """
         Get Gitea credentials for the organization.
 
@@ -734,21 +725,21 @@ class PlatoSandboxClient:
         """
         logger.debug("Getting Gitea credentials")
         lib = _get_lib()
-        result_ptr = lib.plato_gitea_get_credentials(
-            self._client_id.encode('utf-8')
-        )
+        result_ptr = lib.plato_gitea_get_credentials(self._client_id.encode("utf-8"))
 
         result_str = _call_and_free(lib, result_ptr)
         response = json.loads(result_str)
 
-        if 'error' in response:
+        if "error" in response:
             logger.error(f"Failed to get Gitea credentials: {response['error']}")
             raise RuntimeError(f"Failed to get credentials: {response['error']}")
 
-        logger.info(f"Got Gitea credentials for user: {response.get('username')}, org: {response.get('org_name')}")
+        logger.info(
+            f"Got Gitea credentials for user: {response.get('username')}, org: {response.get('org_name')}"
+        )
         return response
 
-    def list_gitea_simulators(self) -> List[Dict[str, Any]]:
+    def list_gitea_simulators(self) -> list[dict[str, Any]]:
         """
         List all simulators with Gitea repository information.
 
@@ -760,21 +751,19 @@ class PlatoSandboxClient:
         """
         logger.debug("Listing Gitea simulators")
         lib = _get_lib()
-        result_ptr = lib.plato_gitea_list_simulators(
-            self._client_id.encode('utf-8')
-        )
+        result_ptr = lib.plato_gitea_list_simulators(self._client_id.encode("utf-8"))
 
         result_str = _call_and_free(lib, result_ptr)
         response = json.loads(result_str)
 
-        if isinstance(response, dict) and 'error' in response:
+        if isinstance(response, dict) and "error" in response:
             logger.error(f"Failed to list Gitea simulators: {response['error']}")
             raise RuntimeError(f"Failed to list simulators: {response['error']}")
 
         logger.info(f"Listed {len(response)} Gitea simulators")
         return response
 
-    def get_gitea_repository(self, simulator_id: int) -> Dict[str, Any]:
+    def get_gitea_repository(self, simulator_id: int) -> dict[str, Any]:
         """
         Get repository information for a simulator.
 
@@ -790,21 +779,24 @@ class PlatoSandboxClient:
         logger.debug(f"Getting Gitea repository for simulator_id={simulator_id}")
         lib = _get_lib()
         result_ptr = lib.plato_gitea_get_simulator_repo(
-            self._client_id.encode('utf-8'),
-            ctypes.c_int(simulator_id)
+            self._client_id.encode("utf-8"), ctypes.c_int(simulator_id)
         )
 
         result_str = _call_and_free(lib, result_ptr)
         response = json.loads(result_str)
 
-        if 'error' in response:
-            logger.error(f"Failed to get repository for simulator {simulator_id}: {response['error']}")
+        if "error" in response:
+            logger.error(
+                f"Failed to get repository for simulator {simulator_id}: {response['error']}"
+            )
             raise RuntimeError(f"Failed to get repository: {response['error']}")
 
-        logger.info(f"Got repository for simulator {simulator_id}: {response.get('name')} (clone_url: {response.get('clone_url')})")
+        logger.info(
+            f"Got repository for simulator {simulator_id}: {response.get('name')} (clone_url: {response.get('clone_url')})"
+        )
         return response
 
-    def create_gitea_repository(self, simulator_id: int) -> Dict[str, Any]:
+    def create_gitea_repository(self, simulator_id: int) -> dict[str, Any]:
         """
         Create a repository for a simulator.
 
@@ -820,21 +812,26 @@ class PlatoSandboxClient:
         logger.debug(f"Creating Gitea repository for simulator_id={simulator_id}")
         lib = _get_lib()
         result_ptr = lib.plato_gitea_create_simulator_repo(
-            self._client_id.encode('utf-8'),
-            ctypes.c_int(simulator_id)
+            self._client_id.encode("utf-8"), ctypes.c_int(simulator_id)
         )
 
         result_str = _call_and_free(lib, result_ptr)
         response = json.loads(result_str)
 
-        if 'error' in response:
-            logger.error(f"Failed to create repository for simulator {simulator_id}: {response['error']}")
+        if "error" in response:
+            logger.error(
+                f"Failed to create repository for simulator {simulator_id}: {response['error']}"
+            )
             raise RuntimeError(f"Failed to create repository: {response['error']}")
 
-        logger.info(f"Created repository for simulator {simulator_id}: {response.get('name')} (clone_url: {response.get('clone_url')})")
+        logger.info(
+            f"Created repository for simulator {simulator_id}: {response.get('name')} (clone_url: {response.get('clone_url')})"
+        )
         return response
 
-    def start_proxy_tunnel(self, public_id: str, remote_port: int, local_port: int = 0) -> Dict[str, Any]:
+    def start_proxy_tunnel(
+        self, public_id: str, remote_port: int, local_port: int = 0
+    ) -> dict[str, Any]:
         """
         Start a proxy tunnel to connect to a port on the sandbox.
 
@@ -849,23 +846,27 @@ class PlatoSandboxClient:
         Raises:
             RuntimeError: If starting the tunnel fails
         """
-        logger.info(f"Starting proxy tunnel: public_id={public_id}, remote_port={remote_port}, local_port={local_port}")
+        logger.info(
+            f"Starting proxy tunnel: public_id={public_id}, remote_port={remote_port}, local_port={local_port}"
+        )
         lib = _get_lib()
         result_ptr = lib.plato_proxytunnel_start(
-            self._client_id.encode('utf-8'),
-            public_id.encode('utf-8'),
+            self._client_id.encode("utf-8"),
+            public_id.encode("utf-8"),
             ctypes.c_int(remote_port),
-            ctypes.c_int(local_port)
+            ctypes.c_int(local_port),
         )
 
         result_str = _call_and_free(lib, result_ptr)
         response = json.loads(result_str)
 
-        if 'error' in response:
+        if "error" in response:
             logger.error(f"Failed to start proxy tunnel: {response['error']}")
             raise RuntimeError(f"Failed to start proxy tunnel: {response['error']}")
 
-        logger.info(f"Proxy tunnel started: tunnel_id={response['tunnel_id']}, local_port={response['local_port']}")
+        logger.info(
+            f"Proxy tunnel started: tunnel_id={response['tunnel_id']}, local_port={response['local_port']}"
+        )
         return response
 
     def stop_proxy_tunnel(self, tunnel_id: str) -> None:
@@ -881,20 +882,19 @@ class PlatoSandboxClient:
         logger.info(f"Stopping proxy tunnel: tunnel_id={tunnel_id}")
         lib = _get_lib()
         result_ptr = lib.plato_proxytunnel_stop(
-            self._client_id.encode('utf-8'),
-            tunnel_id.encode('utf-8')
+            self._client_id.encode("utf-8"), tunnel_id.encode("utf-8")
         )
 
         result_str = _call_and_free(lib, result_ptr)
         response = json.loads(result_str)
 
-        if 'error' in response:
+        if "error" in response:
             logger.error(f"Failed to stop proxy tunnel: {response['error']}")
             raise RuntimeError(f"Failed to stop proxy tunnel: {response['error']}")
 
         logger.info(f"Proxy tunnel stopped: tunnel_id={tunnel_id}")
 
-    def list_proxy_tunnels(self) -> List[Dict[str, Any]]:
+    def list_proxy_tunnels(self) -> list[dict[str, Any]]:
         """
         List all active proxy tunnels.
 
@@ -906,21 +906,19 @@ class PlatoSandboxClient:
         """
         logger.debug("Listing proxy tunnels")
         lib = _get_lib()
-        result_ptr = lib.plato_proxytunnel_list(
-            self._client_id.encode('utf-8')
-        )
+        result_ptr = lib.plato_proxytunnel_list(self._client_id.encode("utf-8"))
 
         result_str = _call_and_free(lib, result_ptr)
         response = json.loads(result_str)
 
-        if isinstance(response, dict) and 'error' in response:
+        if isinstance(response, dict) and "error" in response:
             logger.error(f"Failed to list proxy tunnels: {response['error']}")
             raise RuntimeError(f"Failed to list proxy tunnels: {response['error']}")
 
         logger.info(f"Listed {len(response)} proxy tunnels")
         return response
 
-    def push_to_gitea(self, service_name: str, source_dir: str = "") -> Dict[str, Any]:
+    def push_to_gitea(self, service_name: str, source_dir: str = "") -> dict[str, Any]:
         """
         Push local code to Gitea repository on a timestamped branch.
 
@@ -937,15 +935,15 @@ class PlatoSandboxClient:
         logger.info(f"Pushing to Gitea: service={service_name}, source_dir={source_dir}")
         lib = _get_lib()
         result_ptr = lib.plato_gitea_push_to_hub(
-            self._client_id.encode('utf-8'),
-            service_name.encode('utf-8'),
-            source_dir.encode('utf-8')
+            self._client_id.encode("utf-8"),
+            service_name.encode("utf-8"),
+            source_dir.encode("utf-8"),
         )
 
         result_str = _call_and_free(lib, result_ptr)
         response = json.loads(result_str)
 
-        if 'error' in response:
+        if "error" in response:
             logger.error(f"Failed to push to Gitea: {response['error']}")
             raise RuntimeError(f"Failed to push to Gitea: {response['error']}")
 
@@ -969,30 +967,30 @@ class PlatoSandboxClient:
         logger.info(f"Merging to main: service={service_name}, branch={branch_name}")
         lib = _get_lib()
         result_ptr = lib.plato_gitea_merge_to_main(
-            self._client_id.encode('utf-8'),
-            service_name.encode('utf-8'),
-            branch_name.encode('utf-8')
+            self._client_id.encode("utf-8"),
+            service_name.encode("utf-8"),
+            branch_name.encode("utf-8"),
         )
 
         result_str = _call_and_free(lib, result_ptr)
         response = json.loads(result_str)
 
-        if 'error' in response:
+        if "error" in response:
             logger.error(f"Failed to merge to main: {response['error']}")
             raise RuntimeError(f"Failed to merge to main: {response['error']}")
 
-        git_hash = response.get('git_hash', '')
+        git_hash = response.get("git_hash", "")
         logger.info(f"Merged to main: git_hash={git_hash}")
         return git_hash
 
     def setup_ssh(
         self,
         sandbox: Sandbox,
-        config: Optional[SimConfigDataset] = None,
-        dataset: Optional[str] = None,
+        config: SimConfigDataset | None = None,
+        dataset: str | None = None,
         local_port: int = 2200,
-        username: str = "plato"
-    ) -> Dict[str, str]:
+        username: str = "plato",
+    ) -> dict[str, str]:
         """
         Setup SSH configuration for a sandbox and get connection information.
 
@@ -1041,37 +1039,36 @@ class PlatoSandboxClient:
                     f"No cached config found for sandbox {sandbox.public_id}. "
                     "Please provide config and dataset explicitly."
                 )
-            config = cached['config']
+            config = cached["config"]
             if dataset is None:
-                dataset = cached['dataset']
+                dataset = cached["dataset"]
 
         # Default dataset if still not set
         if dataset is None:
             dataset = "base"
 
         # Convert config to JSON
-        config_dict = config.model_dump(mode='json', exclude_none=True)
+        config_dict = config.model_dump(mode="json", exclude_none=True)
         config_json = json.dumps(config_dict)
 
         lib = _get_lib()
         result_ptr = lib.plato_setup_ssh(
-            self._client_id.encode('utf-8'),
-            self._base_url.encode('utf-8'),
+            self._client_id.encode("utf-8"),
+            self._base_url.encode("utf-8"),
             ctypes.c_int(local_port),
-            sandbox.public_id.encode('utf-8'),
-            username.encode('utf-8'),
-            config_json.encode('utf-8'),
-            dataset.encode('utf-8')
+            sandbox.public_id.encode("utf-8"),
+            username.encode("utf-8"),
+            config_json.encode("utf-8"),
+            dataset.encode("utf-8"),
         )
 
         result_str = _call_and_free(lib, result_ptr)
         try:
             response = json.loads(result_str)
-        except:
+        except Exception:
             logger.error(f"Couldn't parse response: {result_str}")
 
-
-        if 'error' in response:
+        if "error" in response:
             logger.error(f"Failed to setup SSH: {response['error']}")
             raise RuntimeError(f"Failed to setup SSH: {response['error']}")
 
