@@ -1,15 +1,15 @@
+import logging
+import os
+import time
 from datetime import datetime
-from typing import List, Optional, Dict, Any
-from plato.config import get_config
-from plato.models import PlatoTask, PlatoTaskMetadata, PlatoEnvironment
-from plato.models.task import ScoringType
-from plato.exceptions import PlatoClientError
-from plato.models.task import EvaluationResult
+from typing import Any
 
 import aiohttp
-import os
-import logging
-import time
+
+from plato.config import get_config
+from plato.exceptions import PlatoClientError
+from plato.models import PlatoEnvironment, PlatoTask, PlatoTaskMetadata
+from plato.models.task import EvaluationResult, ScoringType
 
 logger = logging.getLogger(__name__)
 
@@ -31,9 +31,9 @@ class Plato:
 
     def __init__(
         self,
-        api_key: Optional[str] = None,
-        base_url: Optional[str] = None,
-        feature_flags: Optional[Dict[str, Any]] = None,
+        api_key: str | None = None,
+        base_url: str | None = None,
+        feature_flags: dict[str, Any] | None = None,
     ):
         """Initialize a new Plato.
 
@@ -47,7 +47,7 @@ class Plato:
         self.api_key = api_key or config.api_key
         self.base_url = base_url or config.base_url
         self.feature_flags = feature_flags or {}
-        self._http_session: Optional[aiohttp.ClientSession] = None
+        self._http_session: aiohttp.ClientSession | None = None
 
     @property
     def http_session(self) -> aiohttp.ClientSession:
@@ -69,9 +69,7 @@ class Plato:
                 sock_connect=60,
             )
             cookie_jar = aiohttp.CookieJar(unsafe=True)
-            self._http_session = aiohttp.ClientSession(
-                timeout=timeout, cookie_jar=cookie_jar
-            )
+            self._http_session = aiohttp.ClientSession(timeout=timeout, cookie_jar=cookie_jar)
             # Attach feature flags as default cookies for all requests, scoped to base_url
             if self.feature_flags:
                 from yarl import URL
@@ -102,9 +100,7 @@ class Plato:
                 # Try to get the error message from the response body
                 error_data = await response.json()
                 error_message = (
-                    error_data.get("error")
-                    or error_data.get("message")
-                    or str(error_data)
+                    error_data.get("error") or error_data.get("message") or str(error_data)
                 )
             except (aiohttp.ContentTypeError, ValueError):
                 # Fallback to status text if we can't parse JSON
@@ -118,17 +114,17 @@ class Plato:
         open_page_on_start: bool = False,
         viewport_width: int = 1920,
         viewport_height: int = 1080,
-        interface_type: Optional[str] = None,
+        interface_type: str | None = None,
         record_network_requests: bool = False,
         record_actions: bool = False,
-        env_config: Optional[Dict[str, Any]] = None,
+        env_config: dict[str, Any] | None = None,
         keepalive: bool = False,
-        alias: Optional[str] = None,
+        alias: str | None = None,
         fast: bool = False,
-        version: Optional[str] = None,
-        tag: Optional[str] = None,
-        dataset: Optional[str] = None,
-        artifact_id: Optional[str] = None,
+        version: str | None = None,
+        tag: str | None = None,
+        dataset: str | None = None,
+        artifact_id: str | None = None,
     ) -> PlatoEnvironment:
         """Create a new Plato environment for the given task.
 
@@ -188,7 +184,7 @@ class Plato:
                 fast=fast,
             )
 
-    async def get_job_status(self, job_id: str) -> Dict[str, Any]:
+    async def get_job_status(self, job_id: str) -> dict[str, Any]:
         """Get the status of a job.
 
         Args:
@@ -226,9 +222,9 @@ class Plato:
             f"{self.base_url}/env/{job_id}/cdp_url", headers=headers
         ) as response:
             data = await response.json()
-            if data["error"] is not None:
-                raise PlatoClientError(data["error"])
-            return data["data"]["cdp_url"]
+            if data.get("error") is not None:
+                raise PlatoClientError(data.get("error"))
+            return data.get("data", {}).get("cdp_url")
 
     async def get_proxy_url(self, job_id: str) -> str:
         """Get the proxy URL for a job.
@@ -245,7 +241,7 @@ class Plato:
                 raise PlatoClientError(data["error"])
             return data["data"]["proxy_url"]
 
-    async def close_environment(self, job_id: str) -> Dict[str, Any]:
+    async def close_environment(self, job_id: str) -> dict[str, Any]:
         """Close an environment.
 
         Args:
@@ -264,7 +260,7 @@ class Plato:
             await self._handle_response_error(response)
             return await response.json()
 
-    async def backup_environment(self, job_id: str) -> Dict[str, Any]:
+    async def backup_environment(self, job_id: str) -> dict[str, Any]:
         """Create a backup of an environment.
 
         Args:
@@ -286,12 +282,12 @@ class Plato:
     async def reset_environment(
         self,
         job_id: str,
-        task: Optional[PlatoTask] = None,
-        agent_version: Optional[str] = None,
-        model: Optional[str] = None,
+        task: PlatoTask | None = None,
+        agent_version: str | None = None,
+        model: str | None = None,
         load_authenticated: bool = False,
         **kwargs,
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         """Reset an environment with an optional new task.
 
         Args:
@@ -325,7 +321,7 @@ class Plato:
 
     async def get_environment_state(
         self, job_id: str, merge_mutations: bool = False
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         """Get the current state of an environment.
 
         Args:
@@ -347,7 +343,7 @@ class Plato:
             data = await response.json()
             return data["data"]["state"]
 
-    async def get_worker_ready(self, job_id: str) -> Dict[str, Any]:
+    async def get_worker_ready(self, job_id: str) -> dict[str, Any]:
         """Check if the worker for this job is ready and healthy.
 
         Args:
@@ -391,9 +387,9 @@ class Plato:
             root_url = self.base_url.split("/api")[0]
             return os.path.join(root_url, "live", f"{job_id}/")
         except aiohttp.ClientError as e:
-            raise PlatoClientError(str(e))
+            raise PlatoClientError(str(e)) from e
 
-    async def send_heartbeat(self, job_id: str) -> Dict[str, Any]:
+    async def send_heartbeat(self, job_id: str) -> dict[str, Any]:
         """Send a heartbeat to keep the environment active.
 
         The environment requires regular heartbeats to stay active. Without
@@ -415,7 +411,7 @@ class Plato:
             await self._handle_response_error(response)
             return await response.json()
 
-    async def process_snapshot(self, session_id: str) -> Dict[str, Any]:
+    async def process_snapshot(self, session_id: str) -> dict[str, Any]:
         """Process a snapshot of the environment.
 
         Args:
@@ -438,9 +434,9 @@ class Plato:
     async def evaluate(
         self,
         session_id: str,
-        value: Optional[Any] = None,
-        agent_version: Optional[str] = None,
-    ) -> Dict[str, Any]:
+        value: Any | None = None,
+        agent_version: str | None = None,
+    ) -> dict[str, Any]:
         """Evaluate the environment.
 
         Args:
@@ -466,9 +462,9 @@ class Plato:
         self,
         session_id: str,
         evaluation_result: EvaluationResult,
-        agent_version: Optional[str] = None,
-        mutations: Optional[List[dict]] = None,
-    ) -> Dict[str, Any]:
+        agent_version: str | None = None,
+        mutations: list[dict] | None = None,
+    ) -> dict[str, Any]:
         """Post an evaluation result to the server.
 
         Args:
@@ -490,9 +486,7 @@ class Plato:
             await self._handle_response_error(response)
             return await response.json()
 
-    async def log(
-        self, session_id: str, log: dict, type: str = "info"
-    ) -> Dict[str, Any]:
+    async def log(self, session_id: str, log: dict, type: str = "info") -> dict[str, Any]:
         """Log a message to the server.
 
         Args:
@@ -514,7 +508,7 @@ class Plato:
             await self._handle_response_error(response)
             return await response.json()
 
-    async def list_simulators(self) -> List[Dict[str, Any]]:
+    async def list_simulators(self) -> list[dict[str, Any]]:
         """List all environments.
 
         Returns:
@@ -528,7 +522,7 @@ class Plato:
             simulators = await response.json()
             return [s for s in simulators if s["enabled"]]
 
-    async def load_tasks(self, simulator_name: str) -> List[PlatoTask]:
+    async def load_tasks(self, simulator_name: str) -> list[PlatoTask]:
         """Load tasks from a simulator.
 
         Args:
@@ -562,13 +556,9 @@ class Plato:
                     is_sample=t.get("isSample", False),
                     simulator_artifact_id=t.get("simulatorArtifactId"),
                     metadata=PlatoTaskMetadata(
-                        reasoning_level=t.get("metadataConfig", {}).get(
-                            "reasoningLevel"
-                        ),
+                        reasoning_level=t.get("metadataConfig", {}).get("reasoningLevel"),
                         skills=t.get("metadataConfig", {}).get("skills", []),
-                        capabilities=t.get("metadataConfig", {}).get(
-                            "capabilities", []
-                        ),
+                        capabilities=t.get("metadataConfig", {}).get("capabilities", []),
                         tags=t.get("metadataConfig", {}).get("tags", []),
                         rejected=t.get("metadataConfig", {}).get("rejected", False),
                     )
@@ -579,9 +569,7 @@ class Plato:
                 for t in test_cases
             ]
 
-    async def list_simulator_tasks_by_id(
-        self, simulator_id: str
-    ) -> List[Dict[str, Any]]:
+    async def list_simulator_tasks_by_id(self, simulator_id: str) -> list[dict[str, Any]]:
         """Get all tasks associated with an environment.
 
         Args:
@@ -602,7 +590,7 @@ class Plato:
             res = await response.json()
             return res["testcases"]
 
-    async def get_active_session(self, job_id: str) -> Dict[str, Any]:
+    async def get_active_session(self, job_id: str) -> dict[str, Any]:
         """Get the active session for a job group.
 
         Args:
@@ -625,7 +613,7 @@ class Plato:
                 raise PlatoClientError(data["error"])
             return data
 
-    async def get_running_sessions_count(self) -> Dict[str, Any]:
+    async def get_running_sessions_count(self) -> dict[str, Any]:
         """Get the current number of running sessions for the user's organization.
 
         Returns:
@@ -643,7 +631,7 @@ class Plato:
 
     # Gitea-related methods for hub commands
 
-    async def get_gitea_info(self) -> Dict[str, Any]:
+    async def get_gitea_info(self) -> dict[str, Any]:
         """Get the current user's Gitea info (auto-provisions if needed).
 
         Returns:
@@ -660,7 +648,7 @@ class Plato:
             await self._handle_response_error(response)
             return await response.json()
 
-    async def list_gitea_simulators(self) -> List[Dict[str, Any]]:
+    async def list_gitea_simulators(self) -> list[dict[str, Any]]:
         """Get simulators that user has access to view repos for.
 
         Returns:
@@ -676,7 +664,7 @@ class Plato:
             await self._handle_response_error(response)
             return await response.json()
 
-    async def get_simulator_repository(self, simulator_id: int) -> Dict[str, Any]:
+    async def get_simulator_repository(self, simulator_id: int) -> dict[str, Any]:
         """Get repository details for a specific simulator.
 
         Args:
@@ -696,7 +684,7 @@ class Plato:
             await self._handle_response_error(response)
             return await response.json()
 
-    async def get_gitea_credentials(self) -> Dict[str, Any]:
+    async def get_gitea_credentials(self) -> dict[str, Any]:
         """Get Gitea admin credentials for the organization.
 
         Returns:
@@ -715,7 +703,7 @@ class Plato:
 
     async def create_simulator(
         self, name: str, description: str = None, sim_type: str = "docker_app"
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         """Create a new simulator.
 
         Args:
@@ -751,7 +739,7 @@ class Plato:
             await self._handle_response_error(response)
             return await response.json()
 
-    async def create_simulator_repository(self, simulator_id: int) -> Dict[str, Any]:
+    async def create_simulator_repository(self, simulator_id: int) -> dict[str, Any]:
         """Create a repository for a simulator.
 
         Args:
@@ -771,7 +759,7 @@ class Plato:
             await self._handle_response_error(response)
             return await response.json()
 
-    async def get_simulator_flows(self, artifact_id: str) -> List[Dict[str, Any]]:
+    async def get_simulator_flows(self, artifact_id: str) -> list[dict[str, Any]]:
         """Get login flows for a simulator artifact.
 
         This method fetches flow configurations from the API using a simulator artifact ID,
@@ -794,9 +782,10 @@ class Plato:
             # Use the flows for authentication
             ```
         """
-        import yaml
         import json
 
+        import yaml
+
         try:
             headers = {"X-API-Key": self.api_key}
             async with self.http_session.get(
@@ -809,9 +798,7 @@ class Plato:
                 try:
                     parsed = json.loads(body_text)
                     flows_yaml = (
-                        parsed.get("data", {}).get("flows")
-                        if isinstance(parsed, dict)
-                        else None
+                        parsed.get("data", {}).get("flows") if isinstance(parsed, dict) else None
                     )
                     if not flows_yaml:
                         raise ValueError("flows missing in JSON body")
@@ -822,14 +809,14 @@ class Plato:
                 flows_data = scripts.get("flows", [])
                 return flows_data
         except Exception as e:
-            raise PlatoClientError(f"Failed to load flows from API: {e}")
+            raise PlatoClientError(f"Failed to load flows from API: {e}") from e
 
     async def login_artifact(
         self,
         artifact_id: str,
         page,
         throw_on_login_error: bool = False,
-        screenshots_dir: Optional[Any] = None,
+        screenshots_dir: Any | None = None,
         dataset: str = "base",
     ) -> None:
         """Login using flows from a simulator artifact.
@@ -863,7 +850,6 @@ class Plato:
         """
         from plato.flow_executor import FlowExecutor
         from plato.models.flow import Flow
-        from pathlib import Path
 
         try:
             flows_data = await self.get_simulator_flows(artifact_id)
@@ -875,9 +861,7 @@ class Plato:
             else:
                 flow_name = dataset
 
-            login_flow = next(
-                (flow for flow in flows_list if flow.name == flow_name), None
-            )
+            login_flow = next((flow for flow in flows_list if flow.name == flow_name), None)
             if not login_flow:
                 raise PlatoClientError(f"No login flow '{flow_name}' found")
 
@@ -892,6 +876,6 @@ class Plato:
                     logger.warning("Failed to login")
         except Exception as e:
             if throw_on_login_error:
-                raise PlatoClientError(f"Login failed: {e}")
+                raise PlatoClientError(f"Login failed: {e}") from e
             else:
                 logger.error(f"Login failed: {e}")
