@@ -1,18 +1,19 @@
-import os
-from urllib.parse import urlparse
-from plato.models.task import CustomEvalConfig
-from plato.models import PlatoTask, EvaluationResult
-from plato.models.flow import Flow
-from typing import List, Optional, Type, Dict, Any, TYPE_CHECKING
-import time
-import threading
-import random
-import logging
-from plato.exceptions import PlatoClientError
-from playwright.sync_api import Page
-import yaml
-from pathlib import Path
 import json
+import logging
+import os
+import random
+import threading
+import time
+from pathlib import Path
+from typing import TYPE_CHECKING, Any
+from urllib.parse import urlparse
+
+import yaml
+from playwright.sync_api import Page
+
+from plato.exceptions import PlatoClientError
+from plato.models.flow import Flow
+from plato.models.task import CustomEvalConfig, EvaluationResult, PlatoTask
 
 logger = logging.getLogger(__name__)
 
@@ -37,13 +38,13 @@ class SyncPlatoEnvironment:
         _heartbeat_thread (Optional[threading.Thread]): Thread for sending periodic heartbeats
     """
 
-    _current_task: Optional[PlatoTask] = None
+    _current_task: PlatoTask | None = None
     _client: "SyncPlato" = None
     id: str = None
     env_id: str = None
-    alias: Optional[str] = None
-    _run_session_id: Optional[str] = None
-    _heartbeat_thread: Optional[threading.Thread] = None
+    alias: str | None = None
+    _run_session_id: str | None = None
+    _heartbeat_thread: threading.Thread | None = None
     _heartbeat_interval: int = 30  # seconds
     _stop_heartbeat: bool = False
 
@@ -51,9 +52,9 @@ class SyncPlatoEnvironment:
         self,
         client: "SyncPlato",
         id: str,
-        env_id: Optional[str] = None,
-        alias: Optional[str] = None,
-        active_session: Optional[str] = None,
+        env_id: str | None = None,
+        alias: str | None = None,
+        active_session: str | None = None,
         fast: bool = False,
     ):
         self._client = client
@@ -71,7 +72,7 @@ class SyncPlatoEnvironment:
         self,
         page: Page,
         throw_on_login_error: bool = False,
-        screenshots_dir: Optional[Path] = None,
+        screenshots_dir: Path | None = None,
         dataset: str = "base",
         from_api: bool = False,
     ) -> None:
@@ -98,9 +99,7 @@ class SyncPlatoEnvironment:
                 try:
                     parsed = json.loads(body_text)
                     flows_yaml = (
-                        parsed.get("data", {}).get("flows")
-                        if isinstance(parsed, dict)
-                        else None
+                        parsed.get("data", {}).get("flows") if isinstance(parsed, dict) else None
                     )
                     if not flows_yaml:
                         raise ValueError("flows missing in JSON body")
@@ -108,12 +107,10 @@ class SyncPlatoEnvironment:
                     flows_yaml = body_text
                 scripts = yaml.safe_load(flows_yaml)
             except Exception as e:
-                raise PlatoClientError(f"Failed to load flows from API: {e}")
+                raise PlatoClientError(f"Failed to load flows from API: {e}") from e
         else:
             if not self.env_id:
-                raise PlatoClientError(
-                    "No env_id set on environment; cannot load flows"
-                )
+                raise PlatoClientError("No env_id set on environment; cannot load flows")
 
             flows_dir = os.path.join(os.path.dirname(__file__), "flows")
             scripts_path = os.path.join(flows_dir, self.env_id, "scripts.yaml")
@@ -121,7 +118,7 @@ class SyncPlatoEnvironment:
                 raise PlatoClientError(
                     f"Flow scripts not found for env_id '{self.env_id}' at {scripts_path}"
                 )
-            with open(scripts_path, "r") as f:
+            with open(scripts_path) as f:
                 scripts = yaml.safe_load(f)
 
         # Parse flows from Watchdog-style format
@@ -147,7 +144,7 @@ class SyncPlatoEnvironment:
             else:
                 logger.warning("Failed to login")
 
-    def wait_for_ready(self, timeout: Optional[float] = None) -> None:
+    def wait_for_ready(self, timeout: float | None = None) -> None:
         """Wait for the environment to be ready.
 
         This method checks both the job status and worker health until everything is ready.
@@ -176,15 +173,11 @@ class SyncPlatoEnvironment:
             time.sleep(current_delay + jitter)
 
             if timeout and time.time() - start_time > timeout:
-                raise RuntimeError(
-                    "Environment failed to start - job never entered running state"
-                )
+                raise RuntimeError("Environment failed to start - job never entered running state")
 
             # Exponential backoff
             current_delay = min(current_delay * 2, max_delay)
-            logger.debug(
-                f"Waiting for job {self.id} to be running: {current_delay} seconds"
-            )
+            logger.debug(f"Waiting for job {self.id} to be running: {current_delay} seconds")
 
         # wait for the worker to be ready and healthy
         current_delay = base_delay  # Reset delay for worker health check
@@ -199,15 +192,11 @@ class SyncPlatoEnvironment:
 
             if timeout and time.time() - start_time > timeout:
                 error_msg = worker_status.get("error", "Unknown error")
-                raise RuntimeError(
-                    f"Environment failed to start - worker not ready: {error_msg}"
-                )
+                raise RuntimeError(f"Environment failed to start - worker not ready: {error_msg}")
 
             # Exponential backoff
             current_delay = min(current_delay * 2, max_delay)
-            logger.debug(
-                f"Waiting for worker {self.id} to be ready: {current_delay} seconds"
-            )
+            logger.debug(f"Waiting for worker {self.id} to be ready: {current_delay} seconds")
 
         # Start the heartbeat thread if not already running
         self._start_heartbeat()
@@ -225,9 +214,9 @@ class SyncPlatoEnvironment:
 
     def __exit__(
         self,
-        exc_type: Optional[Type[BaseException]],
-        exc_val: Optional[BaseException],
-        exc_tb: Optional[Type[BaseException]],
+        exc_type: type[BaseException] | None,
+        exc_val: BaseException | None,
+        exc_tb: type[BaseException] | None,
     ) -> None:
         """Exit the context manager.
 
@@ -255,9 +244,9 @@ class SyncPlatoEnvironment:
 
     def reset(
         self,
-        task: Optional[PlatoTask] = None,
-        agent_version: Optional[str] = None,
-        model: Optional[str] = None,
+        task: PlatoTask | None = None,
+        agent_version: str | None = None,
+        model: str | None = None,
         load_authenticated: bool = False,
         **kwargs,
     ) -> str:
@@ -315,21 +304,17 @@ class SyncPlatoEnvironment:
 
         # Reset stop flag and start a new heartbeat thread
         self._stop_heartbeat = False
-        self._heartbeat_thread = threading.Thread(
-            target=self._heartbeat_loop, daemon=True
-        )
+        self._heartbeat_thread = threading.Thread(target=self._heartbeat_loop, daemon=True)
         self._heartbeat_thread.start()
 
     def _stop_heartbeat_thread(self) -> None:
         """Stop the heartbeat background thread if it's running."""
         if self._heartbeat_thread and self._heartbeat_thread.is_alive():
             self._stop_heartbeat = True
-            self._heartbeat_thread.join(
-                timeout=5.0
-            )  # Wait up to 5 seconds for thread to stop
+            self._heartbeat_thread.join(timeout=5.0)  # Wait up to 5 seconds for thread to stop
             self._heartbeat_thread = None
 
-    def get_state(self, merge_mutations: bool = False) -> Dict[str, Any]:
+    def get_state(self, merge_mutations: bool = False) -> dict[str, Any]:
         """Get the current state of the environment.
 
         Returns:
@@ -342,9 +327,7 @@ class SyncPlatoEnvironment:
             raise PlatoClientError("No active run session. Call reset() first.")
         return self._client.get_environment_state(self.id, merge_mutations)
 
-    def get_state_mutations(
-        self, merge_mutations: bool = False
-    ) -> List[Dict[str, Any]]:
+    def get_state_mutations(self, merge_mutations: bool = False) -> list[dict[str, Any]]:
         """Get a list of state mutations that have occurred in the environment.
 
         Returns:
@@ -356,7 +339,7 @@ class SyncPlatoEnvironment:
         state = self.get_state(merge_mutations)
         return state.get("mutations", [])
 
-    def _get_nested_value(self, data: Dict[str, Any], key_path: str) -> Any:
+    def _get_nested_value(self, data: dict[str, Any], key_path: str) -> Any:
         """Get a value from a nested dictionary using dotted notation.
 
         Args:
@@ -403,9 +386,7 @@ class SyncPlatoEnvironment:
             raise PlatoClientError("No active run session. Call reset() first.")
 
         if not self._current_task or not self._current_task.eval_config:
-            logger.warning(
-                f"No evaluation config found for task: {self._current_task.name}"
-            )
+            logger.warning(f"No evaluation config found for task: {self._current_task.name}")
             raise PlatoClientError("No evaluation config found for task")
 
         eval_config = self._current_task.eval_config
@@ -419,9 +400,7 @@ class SyncPlatoEnvironment:
                 result = eval_config.score_fn(state)
                 if isinstance(result, tuple):
                     success, reason = result
-                    return EvaluationResult(
-                        success=success, reason=None if success else reason
-                    )
+                    return EvaluationResult(success=success, reason=None if success else reason)
                 else:
                     # Handle legacy score functions that return just a boolean
                     return EvaluationResult(
@@ -429,9 +408,7 @@ class SyncPlatoEnvironment:
                         reason=None if result else "Custom evaluation failed",
                     )
             except Exception as e:
-                return EvaluationResult(
-                    success=False, reason=f"Custom evaluation error: {str(e)}"
-                )
+                return EvaluationResult(success=False, reason=f"Custom evaluation error: {str(e)}")
 
         else:
             return EvaluationResult(
@@ -439,7 +416,7 @@ class SyncPlatoEnvironment:
             )
 
     def evaluate(
-        self, value: Optional[Any] = None, agent_version: Optional[str] = None
+        self, value: Any | None = None, agent_version: str | None = None
     ) -> EvaluationResult:
         """Evaluate the current task.
 
@@ -456,9 +433,7 @@ class SyncPlatoEnvironment:
         if not self._run_session_id:
             raise PlatoClientError("No active run session. Call reset() first.")
 
-        if self._current_task and isinstance(
-            self._current_task.eval_config, CustomEvalConfig
-        ):
+        if self._current_task and isinstance(self._current_task.eval_config, CustomEvalConfig):
             evaluation_result = self.get_evaluation_result()
             state = self.get_state()
             state = state.get("state", {})
@@ -509,7 +484,7 @@ class SyncPlatoEnvironment:
             raise PlatoClientError("No active run session. Call reset() first.")
         return self._client.get_live_view_url(self.id)
 
-    def get_proxy_config(self) -> Dict[str, str]:
+    def get_proxy_config(self) -> dict[str, str]:
         """Get the proxy configuration for this environment.
 
         Returns:
@@ -556,7 +531,7 @@ class SyncPlatoEnvironment:
                 "password": self._run_session_id,
             }
         except Exception as e:
-            raise PlatoClientError(str(e))
+            raise PlatoClientError(str(e)) from e
 
     def get_public_url(self) -> str:
         """Get the public URL for accessing this environment.
@@ -595,7 +570,7 @@ class SyncPlatoEnvironment:
             else:
                 raise PlatoClientError("Unknown base URL")
         except Exception as e:
-            raise PlatoClientError(str(e))
+            raise PlatoClientError(str(e)) from e
 
     def close(self) -> None:
         """Clean up and close the environment.
@@ -609,7 +584,7 @@ class SyncPlatoEnvironment:
         # Close the environment through the API
         self._client.close_environment(self.id)
 
-    def backup(self) -> Dict[str, Any]:
+    def backup(self) -> dict[str, Any]:
         """Create a backup of the environment.
 
         Returns:
@@ -621,9 +596,7 @@ class SyncPlatoEnvironment:
         return self._client.backup_environment(self.id)
 
     @staticmethod
-    def from_id(
-        client: "SyncPlato", id: str, fast: bool = False
-    ) -> "SyncPlatoEnvironment":
+    def from_id(client: "SyncPlato", id: str, fast: bool = False) -> "SyncPlatoEnvironment":
         """Create a new environment from an ID.
 
         Returns:
