@@ -4,29 +4,46 @@ Uses Pydantic models for type safety and validation.
 """
 
 import logging
-from typing import Optional
-from pathlib import Path
-import sys
 import os
+import sys
+from pathlib import Path
 from urllib.parse import urljoin
+
 sys.path.insert(0, os.path.dirname(__file__))
 
 from playwright.sync_api import Page
+
 from plato.models.flow import (
-    FlowStep, Flow,
-    WaitForSelectorStep, ClickStep, FillStep, WaitStep, NavigateStep,
-    WaitForUrlStep, CheckElementStep, ScreenshotStep, VerifyTextStep,
-    VerifyUrlStep, VerifyNoErrorsStep, VerifyStep
+    CheckElementStep,
+    ClickStep,
+    FillStep,
+    Flow,
+    FlowStep,
+    NavigateStep,
+    ScreenshotStep,
+    VerifyNoErrorsStep,
+    VerifyStep,
+    VerifyTextStep,
+    VerifyUrlStep,
+    WaitForSelectorStep,
+    WaitForUrlStep,
+    WaitStep,
 )
 
 
 class SyncFlowExecutor:
     """Executes configurable flows for simulator interactions with Pydantic validation (synchronous)."""
 
-    def __init__(self, page: Page, flow: Flow, screenshots_dir: Optional[Path] = None, logger: logging.Logger = logging.getLogger(__name__)):
+    def __init__(
+        self,
+        page: Page,
+        flow: Flow,
+        screenshots_dir: Path | None = None,
+        logger: logging.Logger = logging.getLogger(__name__),
+    ):
         self.page = page
         self.flow = flow
-        
+
         self.screenshots_dir = screenshots_dir
         if self.screenshots_dir:
             self.screenshots_dir.mkdir(parents=True, exist_ok=True)
@@ -36,7 +53,7 @@ class SyncFlowExecutor:
     def _resolve_url(self, url: str) -> str:
         """Resolve a URL against the base URL if it's relative."""
         # If URL is absolute, return as is
-        if url.startswith(('http://', 'https://')):
+        if url.startswith(("http://", "https://")):
             return url
 
         # If we don't have a base URL yet, get it from the current page
@@ -140,7 +157,9 @@ class SyncFlowExecutor:
             self.page.fill(step.selector, str(value))
 
             # Log value safely (mask passwords)
-            display_value = "*" * len(str(value)) if "password" in step.selector.lower() else str(value)
+            display_value = (
+                "*" * len(str(value)) if "password" in step.selector.lower() else str(value)
+            )
             self.logger.info(f"✅ Filled {step.selector} with: {display_value}")
             return True
         except Exception as e:
@@ -174,8 +193,7 @@ class SyncFlowExecutor:
         """Wait for URL to contain specific text."""
         try:
             self.page.wait_for_function(
-                f"window.location.href.includes('{step.url_contains}')",
-                timeout=step.timeout
+                f"window.location.href.includes('{step.url_contains}')", timeout=step.timeout
             )
             self.logger.info(f"✅ URL contains: {step.url_contains}")
             return True
@@ -196,7 +214,9 @@ class SyncFlowExecutor:
                 self.logger.info(f"✅ Element absent as expected: {step.selector}")
                 return True
             else:
-                self.logger.error(f"❌ Element check failed: {step.selector} (expected: {step.should_exist}, found: {exists})")
+                self.logger.error(
+                    f"❌ Element check failed: {step.selector} (expected: {step.should_exist}, found: {exists})"
+                )
                 return False
         except Exception as e:
             self.logger.error(f"❌ Element check error: {step.selector} - {e}")
@@ -241,10 +261,14 @@ class SyncFlowExecutor:
             if element:
                 is_visible = element.is_visible()
                 if is_visible:
-                    self.logger.info(f"✅ Verification passed: Element is visible - {step.selector}")
+                    self.logger.info(
+                        f"✅ Verification passed: Element is visible - {step.selector}"
+                    )
                     return True
                 else:
-                    self.logger.error(f"❌ Verification failed: Element exists but not visible - {step.selector}")
+                    self.logger.error(
+                        f"❌ Verification failed: Element exists but not visible - {step.selector}"
+                    )
                     return False
             else:
                 self.logger.error(f"❌ Verification failed: Element not found - {step.selector}")
@@ -262,20 +286,30 @@ class SyncFlowExecutor:
                 if actual_text:
                     if step.contains:
                         if step.text in actual_text:
-                            self.logger.info(f"✅ Verification passed: Text contains '{step.text}' - {step.selector}")
+                            self.logger.info(
+                                f"✅ Verification passed: Text contains '{step.text}' - {step.selector}"
+                            )
                             return True
                         else:
-                            self.logger.error(f"❌ Verification failed: Text '{actual_text}' does not contain '{step.text}' - {step.selector}")
+                            self.logger.error(
+                                f"❌ Verification failed: Text '{actual_text}' does not contain '{step.text}' - {step.selector}"
+                            )
                             return False
                     else:
                         if step.text == actual_text.strip():
-                            self.logger.info(f"✅ Verification passed: Text matches exactly '{step.text}' - {step.selector}")
+                            self.logger.info(
+                                f"✅ Verification passed: Text matches exactly '{step.text}' - {step.selector}"
+                            )
                             return True
                         else:
-                            self.logger.error(f"❌ Verification failed: Text '{actual_text}' does not match '{step.text}' - {step.selector}")
+                            self.logger.error(
+                                f"❌ Verification failed: Text '{actual_text}' does not match '{step.text}' - {step.selector}"
+                            )
                             return False
                 else:
-                    self.logger.error(f"❌ Verification failed: Element has no text content - {step.selector}")
+                    self.logger.error(
+                        f"❌ Verification failed: Element has no text content - {step.selector}"
+                    )
                     return False
             else:
                 self.logger.error(f"❌ Verification failed: Element not found - {step.selector}")
@@ -291,10 +325,14 @@ class SyncFlowExecutor:
             actual_count = len(elements)
 
             if actual_count == step.count:
-                self.logger.info(f"✅ Verification passed: Found {actual_count} elements matching '{step.selector}'")
+                self.logger.info(
+                    f"✅ Verification passed: Found {actual_count} elements matching '{step.selector}'"
+                )
                 return True
             else:
-                self.logger.error(f"❌ Verification failed: Expected {step.count} elements, found {actual_count} - {step.selector}")
+                self.logger.error(
+                    f"❌ Verification failed: Expected {step.count} elements, found {actual_count} - {step.selector}"
+                )
                 return False
         except Exception as e:
             self.logger.error(f"❌ Verification error: {step.selector} - {e}")
@@ -310,14 +348,20 @@ class SyncFlowExecutor:
                     self.logger.info(f"✅ Verification passed: Page title contains '{step.title}'")
                     return True
                 else:
-                    self.logger.error(f"❌ Verification failed: Page title '{actual_title}' does not contain '{step.title}'")
+                    self.logger.error(
+                        f"❌ Verification failed: Page title '{actual_title}' does not contain '{step.title}'"
+                    )
                     return False
             else:
                 if step.title == actual_title:
-                    self.logger.info(f"✅ Verification passed: Page title matches exactly '{step.title}'")
+                    self.logger.info(
+                        f"✅ Verification passed: Page title matches exactly '{step.title}'"
+                    )
                     return True
                 else:
-                    self.logger.error(f"❌ Verification failed: Page title '{actual_title}' does not match '{step.title}'")
+                    self.logger.error(
+                        f"❌ Verification failed: Page title '{actual_title}' does not match '{step.title}'"
+                    )
                     return False
         except Exception as e:
             self.logger.error(f"❌ Verification error: {e}")
@@ -328,13 +372,14 @@ class SyncFlowExecutor:
         try:
             # Add timestamp to filename for chronological sorting
             import time
+
             # Use epoch time in milliseconds for guaranteed chronological sorting
             timestamp_ms = int(time.time() * 1000)
 
             # Extract base name and extension
             filename = step.filename
-            if '.' in filename:
-                name, ext = filename.rsplit('.', 1)
+            if "." in filename:
+                name, ext = filename.rsplit(".", 1)
                 timestamped_filename = f"{timestamp_ms}_{name}.{ext}"
             else:
                 timestamped_filename = f"{timestamp_ms}_{filename}.png"
@@ -343,7 +388,9 @@ class SyncFlowExecutor:
             if self.screenshots_dir:
                 screenshot_path = self.screenshots_dir / timestamped_filename
                 self.page.screenshot(path=str(screenshot_path), full_page=step.full_page)
-                self.logger.info(f"📸 Screenshot taken: {step.description or 'Screenshot'} -> {screenshot_path}")
+                self.logger.info(
+                    f"📸 Screenshot taken: {step.description or 'Screenshot'} -> {screenshot_path}"
+                )
             return True
         except Exception as e:
             self.logger.error(f"❌ Screenshot failed: {e}")
@@ -359,13 +406,19 @@ class SyncFlowExecutor:
                 self.logger.info(f"✅ Verification passed: Text '{step.text}' found on page")
                 return True
             elif not step.should_exist and not text_found:
-                self.logger.info(f"✅ Verification passed: Text '{step.text}' not found on page (as expected)")
+                self.logger.info(
+                    f"✅ Verification passed: Text '{step.text}' not found on page (as expected)"
+                )
                 return True
             else:
                 if step.should_exist:
-                    self.logger.error(f"❌ Verification failed: Text '{step.text}' not found on page")
+                    self.logger.error(
+                        f"❌ Verification failed: Text '{step.text}' not found on page"
+                    )
                 else:
-                    self.logger.error(f"❌ Verification failed: Text '{step.text}' found on page (should not exist)")
+                    self.logger.error(
+                        f"❌ Verification failed: Text '{step.text}' found on page (should not exist)"
+                    )
                 return False
         except Exception as e:
             self.logger.error(f"❌ Text verification error: {e}")
@@ -381,14 +434,18 @@ class SyncFlowExecutor:
                     self.logger.info(f"✅ Verification passed: URL contains '{step.url}'")
                     return True
                 else:
-                    self.logger.error(f"❌ Verification failed: URL '{current_url}' does not contain '{step.url}'")
+                    self.logger.error(
+                        f"❌ Verification failed: URL '{current_url}' does not contain '{step.url}'"
+                    )
                     return False
             else:
                 if step.url == current_url:
                     self.logger.info(f"✅ Verification passed: URL matches exactly '{step.url}'")
                     return True
                 else:
-                    self.logger.error(f"❌ Verification failed: URL '{current_url}' does not match '{step.url}'")
+                    self.logger.error(
+                        f"❌ Verification failed: URL '{current_url}' does not match '{step.url}'"
+                    )
                     return False
         except Exception as e:
             self.logger.error(f"❌ URL verification error: {e}")
@@ -405,7 +462,9 @@ class SyncFlowExecutor:
                     if element.is_visible():
                         text = element.text_content()
                         if text and text.strip():
-                            errors_found.append(f"Error found with selector '{selector}': {text.strip()}")
+                            errors_found.append(
+                                f"Error found with selector '{selector}': {text.strip()}"
+                            )
 
             if not errors_found:
                 self.logger.info("✅ Verification passed: No error indicators found on page")
