@@ -1,18 +1,17 @@
+import logging
+import os
+import time
 from datetime import datetime
 from pathlib import Path
-from typing import List, Optional, Dict, Any
-from plato.config import get_config
-from plato.models import PlatoTask, PlatoTaskMetadata
-from plato.models.task import ScoringType
-from plato.exceptions import PlatoClientError
-from plato.models.task import EvaluationResult
-from plato.sync_env import SyncPlatoEnvironment
+from typing import Any
 
-import os
-import logging
-import time
 import requests
 
+from plato.config import get_config
+from plato.exceptions import PlatoClientError
+from plato.models import PlatoTask, PlatoTaskMetadata
+from plato.models.task import EvaluationResult, ScoringType
+from plato.sync_env import SyncPlatoEnvironment
 
 logger = logging.getLogger(__name__)
 
@@ -33,9 +32,9 @@ class SyncPlato:
 
     def __init__(
         self,
-        api_key: Optional[str] = None,
-        base_url: Optional[str] = None,
-        feature_flags: Optional[Dict[str, Any]] = None,
+        api_key: str | None = None,
+        base_url: str | None = None,
+        feature_flags: dict[str, Any] | None = None,
     ):
         """Initialize a new SyncPlato.
 
@@ -49,7 +48,7 @@ class SyncPlato:
         self.api_key = api_key or config.api_key
         self.base_url = base_url or config.base_url
         self.feature_flags = feature_flags or {}
-        self._http_session: Optional[requests.Session] = None
+        self._http_session: requests.Session | None = None
 
     @property
     def http_session(self) -> requests.Session:
@@ -87,9 +86,7 @@ class SyncPlato:
                 # Try to get the error message from the response body
                 error_data = response.json()
                 error_message = (
-                    error_data.get("error")
-                    or error_data.get("message")
-                    or str(error_data)
+                    error_data.get("error") or error_data.get("message") or str(error_data)
                 )
             except (ValueError, requests.exceptions.JSONDecodeError):
                 # Fallback to status text if we can't parse JSON
@@ -103,17 +100,17 @@ class SyncPlato:
         open_page_on_start: bool = False,
         viewport_width: int = 1920,
         viewport_height: int = 1080,
-        interface_type: Optional[str] = None,
+        interface_type: str | None = None,
         record_network_requests: bool = False,
         record_actions: bool = False,
-        env_config: Optional[Dict[str, Any]] = None,
+        env_config: dict[str, Any] | None = None,
         keepalive: bool = False,
-        alias: Optional[str] = None,
+        alias: str | None = None,
         fast: bool = False,
-        version: Optional[str] = None,
-        tag: Optional[str] = None,
-        dataset: Optional[str] = None,
-        artifact_id: Optional[str] = None,
+        version: str | None = None,
+        tag: str | None = None,
+        dataset: str | None = None,
+        artifact_id: str | None = None,
     ) -> SyncPlatoEnvironment:
         """Create a new Plato environment for the given task.
 
@@ -168,7 +165,7 @@ class SyncPlato:
             fast=fast,
         )
 
-    def get_job_status(self, job_id: str) -> Dict[str, Any]:
+    def get_job_status(self, job_id: str) -> dict[str, Any]:
         """Get the status of a job.
 
         Args:
@@ -201,9 +198,9 @@ class SyncPlato:
         """
         response = self.http_session.get(f"{self.base_url}/env/{job_id}/cdp_url")
         data = response.json()
-        if data["error"] is not None:
-            raise PlatoClientError(data["error"])
-        return data["data"]["cdp_url"]
+        if data.get("error") is not None:
+            raise PlatoClientError(data.get("error"))
+        return data.get("data", {}).get("cdp_url")
 
     def get_proxy_url(self, job_id: str) -> str:
         """Get the proxy URL for a job.
@@ -224,7 +221,7 @@ class SyncPlato:
             raise PlatoClientError(data["error"])
         return data["data"]["proxy_url"]
 
-    def close_environment(self, job_id: str) -> Dict[str, Any]:
+    def close_environment(self, job_id: str) -> dict[str, Any]:
         """Close an environment.
 
         Args:
@@ -240,7 +237,7 @@ class SyncPlato:
         self._handle_response_error(response)
         return response.json()
 
-    def backup_environment(self, job_id: str) -> Dict[str, Any]:
+    def backup_environment(self, job_id: str) -> dict[str, Any]:
         """Create a backup of an environment.
 
         Args:
@@ -259,12 +256,12 @@ class SyncPlato:
     def reset_environment(
         self,
         job_id: str,
-        task: Optional[PlatoTask] = None,
-        agent_version: Optional[str] = None,
-        model: Optional[str] = None,
+        task: PlatoTask | None = None,
+        agent_version: str | None = None,
+        model: str | None = None,
         load_authenticated: bool = False,
         **kwargs,
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         """Reset an environment with an optional new task.
 
         Args:
@@ -297,9 +294,7 @@ class SyncPlato:
         self._handle_response_error(response)
         return response.json()
 
-    def get_environment_state(
-        self, job_id: str, merge_mutations: bool = False
-    ) -> Dict[str, Any]:
+    def get_environment_state(self, job_id: str, merge_mutations: bool = False) -> dict[str, Any]:
         """Get the current state of an environment.
 
         Args:
@@ -320,7 +315,7 @@ class SyncPlato:
         data = response.json()
         return data["data"]["state"]
 
-    def get_worker_ready(self, job_id: str) -> Dict[str, Any]:
+    def get_worker_ready(self, job_id: str) -> dict[str, Any]:
         """Check if the worker for this job is ready and healthy.
 
         Args:
@@ -356,9 +351,9 @@ class SyncPlato:
             root_url = self.base_url.split("/api")[0]
             return os.path.join(root_url, "live", f"{job_id}/")
         except requests.RequestException as e:
-            raise PlatoClientError(str(e))
+            raise PlatoClientError(str(e)) from e
 
-    def send_heartbeat(self, job_id: str) -> Dict[str, Any]:
+    def send_heartbeat(self, job_id: str) -> dict[str, Any]:
         """Send a heartbeat to keep the environment active.
 
         Args:
@@ -374,7 +369,7 @@ class SyncPlato:
         self._handle_response_error(response)
         return response.json()
 
-    def process_snapshot(self, session_id: str) -> Dict[str, Any]:
+    def process_snapshot(self, session_id: str) -> dict[str, Any]:
         """Process a snapshot of the environment.
 
         Args:
@@ -386,18 +381,16 @@ class SyncPlato:
         Raises:
             requests.RequestException: If the API request fails.
         """
-        response = self.http_session.post(
-            f"{self.base_url}/snapshot/process/{session_id}"
-        )
+        response = self.http_session.post(f"{self.base_url}/snapshot/process/{session_id}")
         self._handle_response_error(response)
         return response.json()
 
     def evaluate(
         self,
         session_id: str,
-        value: Optional[Any] = None,
-        agent_version: Optional[str] = None,
-    ) -> Dict[str, Any]:
+        value: Any | None = None,
+        agent_version: str | None = None,
+    ) -> dict[str, Any]:
         """Evaluate the environment.
 
         Args:
@@ -427,9 +420,9 @@ class SyncPlato:
         self,
         session_id: str,
         evaluation_result: EvaluationResult,
-        agent_version: Optional[str] = None,
-        mutations: Optional[List[dict]] = None,
-    ) -> Dict[str, Any]:
+        agent_version: str | None = None,
+        mutations: list[dict] | None = None,
+    ) -> dict[str, Any]:
         """Post an evaluation result to the server.
 
         Args:
@@ -457,7 +450,7 @@ class SyncPlato:
         self._handle_response_error(response)
         return response.json()
 
-    def log(self, session_id: str, log: dict, type: str = "info") -> Dict[str, Any]:
+    def log(self, session_id: str, log: dict, type: str = "info") -> dict[str, Any]:
         """Log a message to the server.
 
         Args:
@@ -483,7 +476,7 @@ class SyncPlato:
         self._handle_response_error(response)
         return response.json()
 
-    def list_simulators(self) -> List[Dict[str, Any]]:
+    def list_simulators(self) -> list[dict[str, Any]]:
         """List all environments.
 
         Returns:
@@ -497,7 +490,7 @@ class SyncPlato:
         simulators = response.json()
         return [s for s in simulators if s["enabled"]]
 
-    def load_tasks(self, simulator_name: str) -> List[PlatoTask]:
+    def load_tasks(self, simulator_name: str) -> list[PlatoTask]:
         """Load tasks from a simulator.
 
         Args:
@@ -548,7 +541,7 @@ class SyncPlato:
             for t in test_cases
         ]
 
-    def get_active_session(self, job_id: str) -> Dict[str, Any]:
+    def get_active_session(self, job_id: str) -> dict[str, Any]:
         """Get the active session for a job group.
 
         Args:
@@ -568,7 +561,7 @@ class SyncPlato:
             raise PlatoClientError(data["error"])
         return data
 
-    def get_running_sessions_count(self) -> Dict[str, Any]:
+    def get_running_sessions_count(self) -> dict[str, Any]:
         """Get the current number of running sessions for the user's organization.
 
         Returns:
@@ -577,13 +570,11 @@ class SyncPlato:
         Raises:
             requests.RequestException: If the API request fails.
         """
-        response = self.http_session.get(
-            f"{self.base_url}/user/organization/running-sessions"
-        )
+        response = self.http_session.get(f"{self.base_url}/user/organization/running-sessions")
         self._handle_response_error(response)
         return response.json()
 
-    def get_simulator_flows(self, artifact_id: str) -> List[Dict[str, Any]]:
+    def get_simulator_flows(self, artifact_id: str) -> list[dict[str, Any]]:
         """Get login flows for a simulator artifact.
 
         This method fetches flow configurations from the API using a simulator artifact ID,
@@ -606,9 +597,10 @@ class SyncPlato:
             # Use the flows for authentication
             ```
         """
-        import yaml
         import json
 
+        import yaml
+
         try:
             headers = {"X-API-Key": self.api_key}
             response = self.http_session.get(
@@ -621,9 +613,7 @@ class SyncPlato:
             try:
                 parsed = json.loads(body_text)
                 flows_yaml = (
-                    parsed.get("data", {}).get("flows")
-                    if isinstance(parsed, dict)
-                    else None
+                    parsed.get("data", {}).get("flows") if isinstance(parsed, dict) else None
                 )
                 if not flows_yaml:
                     raise ValueError("flows missing in JSON body")
@@ -634,14 +624,14 @@ class SyncPlato:
             flows_data = scripts.get("flows", [])
             return flows_data
         except Exception as e:
-            raise PlatoClientError(f"Failed to load flows from API: {e}")
+            raise PlatoClientError(f"Failed to load flows from API: {e}") from e
 
     def login_artifact(
         self,
         artifact_id: str,
         page,
         throw_on_login_error: bool = False,
-        screenshots_dir: Optional[Path] = None,
+        screenshots_dir: Path | None = None,
         dataset: str = "base",
     ) -> None:
         """Login using flows from a simulator artifact.
@@ -673,8 +663,8 @@ class SyncPlato:
                 # Page is now authenticated
             ```
         """
-        from plato.sync_flow_executor import SyncFlowExecutor
         from plato.models.flow import Flow
+        from plato.sync_flow_executor import SyncFlowExecutor
 
         try:
             flows_data = self.get_simulator_flows(artifact_id)
@@ -686,9 +676,7 @@ class SyncPlato:
             else:
                 flow_name = dataset
 
-            login_flow = next(
-                (flow for flow in flows_list if flow.name == flow_name), None
-            )
+            login_flow = next((flow for flow in flows_list if flow.name == flow_name), None)
             if not login_flow:
                 raise PlatoClientError(f"No login flow '{flow_name}' found")
 
@@ -702,6 +690,6 @@ class SyncPlato:
                     logger.warning("Failed to login")
         except Exception as e:
             if throw_on_login_error:
-                raise PlatoClientError(f"Login failed: {e}")
+                raise PlatoClientError(f"Login failed: {e}") from e
             else:
                 logger.error(f"Login failed: {e}")
