@@ -7,7 +7,7 @@ import sys
 from pathlib import Path
 
 # Add parent directory to path
-sys.path.insert(0, str(Path(__file__).parent.parent / 'src'))
+sys.path.insert(0, str(Path(__file__).parent.parent / "src"))
 
 print("Testing Plato Sandbox SDK import...")
 print()
@@ -16,6 +16,7 @@ print()
 print("1. Testing import...")
 try:
     from plato.sandbox_sdk import PlatoSandboxClient
+
     print("   ✅ Import successful")
 except ImportError as e:
     print(f"   ❌ Import failed: {e}")
@@ -26,6 +27,7 @@ print()
 print("2. Testing library discovery...")
 try:
     from plato.sandbox_sdk import _find_lib
+
     lib_path = _find_lib()
     print(f"   ✅ Found library: {lib_path}")
 except FileNotFoundError as e:
@@ -37,6 +39,7 @@ print()
 print("3. Testing library loading...")
 try:
     from plato.sandbox_sdk import _get_lib
+
     lib = _get_lib()
     print("   ✅ Library loaded successfully")
 except Exception as e:
@@ -47,7 +50,7 @@ except Exception as e:
 print()
 print("4. Testing client initialization...")
 try:
-    client = PlatoSandboxClient('test-key')
+    client = PlatoSandboxClient("test-key")
     print(f"   ✅ Client created: {client._client_id}")
 except Exception as e:
     print(f"   ❌ Client creation failed: {e}")
